@@ -1,5 +1,7 @@
 import subprocess
 import time
+from uuid import uuid4
+
 import pytest
 from thrift.transport import TSocket, TTransport
 from thrift.transport.TSocket import TTransportException
@@ -33,12 +35,22 @@ def mapd_server():
         pass
     else:
         # not yet running...
-        subprocess.check_output(['docker', 'run', '-d',
-                                 '--ipc=host',
-                                 '-v', '/dev:/dev',
-                                 '-p', '6274:6274',
-                                 '-p', '9092:9092',
-                                 '--name=mapd', 'omnisci/core-os-cpu:latest'])
+        subprocess.check_output(
+            [
+                'docker',
+                'run',
+                '-d',
+                '--ipc=host',
+                '-v',
+                '/dev:/dev',
+                '-p',
+                '6274:6274',
+                '-p',
+                '9092:9092',
+                '--name=mapd',
+                'omnisci/core-os-cpu:latest',
+            ]
+        )
         # yield and stop afterwards?
         assert _check_open()
         # Takes some time to start up. Unfortunately even trying to connect
@@ -51,8 +63,14 @@ def con(mapd_server):
     """
     Fixture to provide Connection for tests run against live OmniSci instance
     """
-    return connect(user="admin", password='HyperInteractive', host='localhost',
-                   port=6274, protocol='binary', dbname='omnisci')
+    return connect(
+        user="admin",
+        password='HyperInteractive',
+        host='localhost',
+        port=6274,
+        protocol='binary',
+        dbname='omnisci',
+    )
 
 
 @pytest.fixture
@@ -65,7 +83,7 @@ def no_gpu():
     """Check for the required GPU dependencies"""
     try:
         from numba import cuda
-        import cudf # noqa
+        import cudf  # noqa
 
         try:
             cuda.select_device(0)
@@ -78,8 +96,12 @@ def no_gpu():
 
 def gen_string():
     """Generate a random string sequence for use in _tests_table_no_nulls"""
-    return ''.join([random.choice(string.ascii_letters + string.digits)
-                    for n in range(10)])
+    return ''.join(
+        [
+            random.choice(string.ascii_letters + string.digits)
+            for n in range(10)
+        ]
+    )
 
 
 def _tests_table_no_nulls(n_samples):
@@ -90,25 +112,24 @@ def _tests_table_no_nulls(n_samples):
 
     np.random.seed(12345)
 
-    tinyint_ = np.random.randint(low=-127,
-                                 high=127,
-                                 size=n_samples,
-                                 dtype='int8')
+    tinyint_ = np.random.randint(
+        low=-127, high=127, size=n_samples, dtype='int8'
+    )
 
-    smallint_ = np.random.randint(low=-32767,
-                                  high=32767,
-                                  size=n_samples,
-                                  dtype='int16')
+    smallint_ = np.random.randint(
+        low=-32767, high=32767, size=n_samples, dtype='int16'
+    )
 
-    int_ = np.random.randint(low=-2147483647,
-                             high=2147483647,
-                             size=n_samples,
-                             dtype='int32')
+    int_ = np.random.randint(
+        low=-2147483647, high=2147483647, size=n_samples, dtype='int32'
+    )
 
-    bigint_ = np.random.randint(low=-9223372036854775807,
-                                high=9223372036854775807,
-                                size=n_samples,
-                                dtype='int64')
+    bigint_ = np.random.randint(
+        low=-9223372036854775807,
+        high=9223372036854775807,
+        size=n_samples,
+        dtype='int64',
+    )
 
     # float and double ranges slightly lower than we support, full width
     # causes an error in np.linspace that's not worth tracking down
@@ -119,12 +140,16 @@ def _tests_table_no_nulls(n_samples):
 
     # effective date range of 1904 to 2035
     # TODO: validate if this is an Arrow limitation, outside this range fails
-    date_ = [datetime.date(1970, 1, 1) + datetime.timedelta(days=int(x))
-             for x in np.random.randint(-24000, 24000, size=n_samples)]
+    date_ = [
+        datetime.date(1970, 1, 1) + datetime.timedelta(days=int(x))
+        for x in np.random.randint(-24000, 24000, size=n_samples)
+    ]
 
-    datetime_ = [datetime.datetime(1970, 1, 1) +
-                 datetime.timedelta(days=int(x), minutes=int(x))
-                 for x in np.random.randint(-24000, 24000, size=n_samples)]
+    datetime_ = [
+        datetime.datetime(1970, 1, 1)
+        + datetime.timedelta(days=int(x), minutes=int(x))
+        for x in np.random.randint(-24000, 24000, size=n_samples)
+    ]
 
     time_h = np.random.randint(0, 24, size=n_samples)
     time_m = np.random.randint(0, 60, size=n_samples)
@@ -147,21 +172,33 @@ def _tests_table_no_nulls(n_samples):
     poly_ = pd.read_csv("tests/data/polys_10000.zip", header=None).values
     poly_ = np.squeeze(poly_)
 
-    d = {'tinyint_': tinyint_,
-         'smallint_': smallint_,
-         'int_': int_,
-         'bigint_': bigint_,
-         'float_': float_,
-         'double_': double_,
-         'bool_': bool_,
-         'date_': date_,
-         'datetime_': datetime_,
-         'time_': time_,
-         'text_': text_,
-         'point_': point_,
-         'line_': line_,
-         'mpoly_': mpoly_,
-         'poly_': poly_
-         }
+    d = {
+        'tinyint_': tinyint_,
+        'smallint_': smallint_,
+        'int_': int_,
+        'bigint_': bigint_,
+        'float_': float_,
+        'double_': double_,
+        'bool_': bool_,
+        'date_': date_,
+        'datetime_': datetime_,
+        'time_': time_,
+        'text_': text_,
+        'point_': point_,
+        'line_': line_,
+        'mpoly_': mpoly_,
+        'poly_': poly_,
+    }
 
     return pd.DataFrame(d)
+
+
+@pytest.fixture
+def tmp_table(con) -> str:
+    table_name = 'table_{}'.format(uuid4().hex)
+    con.execute("drop table if exists {};".format(table_name))
+
+    try:
+        yield table_name
+    finally:
+        con.execute("drop table if exists {};".format(table_name))
