@@ -1,5 +1,8 @@
-import pytest
+from decimal import Decimal
 import datetime
+
+import pytest
+
 from pymapd._loaders import _build_input_rows
 from pymapd import _pandas_loaders
 from pymapd._parsers import ColumnDetails
@@ -40,7 +43,7 @@ def get_col_types(col_properties: dict):
     )
 
     return [
-        ColumnDetails(**properties, **common_col_params)
+        ColumnDetails(**{**common_col_params, **properties})
         for properties in col_properties
     ]
 
@@ -52,6 +55,7 @@ def get_expected(data, col_properties):
         'DOUBLE': 'real_col',
         'STR': 'str_col',
         'TIMESTAMP': 'int_col',
+        'DECIMAL': 'int_col',
     }
     _map_col_types.update(
         {k: 'str_col' for k in _pandas_loaders.GEO_TYPE_NAMES}
@@ -89,6 +93,12 @@ def get_expected(data, col_properties):
                     data[prop['name']] = (
                         data[prop['name']].astype(int) // 10 ** 9
                     )
+            elif prop['type'] == 'DECIMAL':
+                # data = (data * 10 ** precision).astype(int) \
+                #   * 10 ** (scale - precision)
+                data[prop['name']] = (
+                    data[prop['name']] * 10 ** prop['precision']
+                ).astype(int) * 10 ** (prop['scale'] - prop['precision'])
 
             col = TColumn(
                 data=TColumnData(
@@ -207,14 +217,36 @@ class TestLoaders:
                                 '%Y-%m-%d %H:%M:%S.%f',
                             ),
                         ],
+                        'f': [
+                            Decimal('1.1234'),
+                            Decimal('2.2345'),
+                            Decimal('3.3456'),
+                        ],
                     }
                 ),
                 [
                     {'name': 'a', 'type': 'INT', 'is_array': True},
                     {'name': 'b', 'type': 'DOUBLE', 'is_array': True},
                     {'name': 'c', 'type': 'INT', 'is_array': False},
-                    {'name': 'd', 'type': 'TIMESTAMP', 'is_array': False},
-                    {'name': 'e', 'type': 'TIMESTAMP', 'is_array': False},
+                    {
+                        'name': 'd',
+                        'type': 'TIMESTAMP',
+                        'is_array': False,
+                        'precision': 9,
+                    },
+                    {
+                        'name': 'e',
+                        'type': 'TIMESTAMP',
+                        'is_array': False,
+                        'precision': 0,
+                    },
+                    {
+                        'name': 'f',
+                        'type': 'DECIMAL',
+                        'is_array': False,
+                        'scale': 10,
+                        'precision': 4,
+                    },
                 ],
                 id='mult-cols-mix-array-not-null',
             ),
@@ -367,7 +399,14 @@ class TestLoaders:
             ColumnDetails(name='text_', type='STR', **common_col_params),
             ColumnDetails(name='time_', type='TIME', **common_col_params),
             ColumnDetails(
-                name='timestamp_', type='TIMESTAMP', **common_col_params
+                name='timestamp_',
+                type='TIMESTAMP',
+                nullable=True,
+                precision=0,
+                scale=0,
+                comp_param=0,
+                encoding='NONE',
+                is_array=False,
             ),
             ColumnDetails(name='date_', type='DATE', **common_col_params),
         ]
@@ -435,7 +474,6 @@ class TestLoaders:
     def test_build_table_columnar_nulls(self):
         common_col_params = dict(
             nullable=True,
-            precision=0,
             scale=0,
             comp_param=0,
             encoding='NONE',
@@ -443,17 +481,36 @@ class TestLoaders:
         )
 
         col_types = [
-            ColumnDetails(name='boolean_', type='BOOL', **common_col_params),
-            ColumnDetails(name='int_', type='INT', **common_col_params),
-            ColumnDetails(name='bigint_', type='BIGINT', **common_col_params),
-            ColumnDetails(name='double_', type='DOUBLE', **common_col_params),
-            ColumnDetails(name='varchar_', type='STR', **common_col_params),
-            ColumnDetails(name='text_', type='STR', **common_col_params),
-            ColumnDetails(name='time_', type='TIME', **common_col_params),
             ColumnDetails(
-                name='timestamp_', type='TIMESTAMP', **common_col_params
+                name='boolean_', type='BOOL', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='int_', type='INT', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='bigint_', type='BIGINT', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='double_', type='DOUBLE', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='varchar_', type='STR', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='text_', type='STR', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='time_', type='TIME', precision=0, **common_col_params
+            ),
+            ColumnDetails(
+                name='timestamp_',
+                type='TIMESTAMP',
+                **common_col_params,
+                precision=0,
+            ),
+            ColumnDetails(
+                name='date_', type='DATE', precision=0, **common_col_params
             ),
-            ColumnDetails(name='date_', type='DATE', **common_col_params),
         ]
 
         data = pd.DataFrame(
